# emilys

Electron Microscopy Image anaLYsis tools

Juri Barthel
Forschungszentrum Juelich GmbH, Juelich, Germany
Dec 2020

## Installation

To install, copy this source tree to some place, where your Python environment is able to find it.

A package installer is in preparation to install via
```
pip install emilys
```
